=========
Reference
=========

.. toctree::

   ballot/index
   converter_ballot/index
   elimination/index
   matrix/index
   priority/index
   profile/index
   rule_in_general/index
   rule_in_particular/index
   scale/index
   scorer/index
   utils/index
